#!/bin/bash

BASEDIR="/home/nasroot/foscripts"
HOMEDIR="/home/nasroot"

# Prepare trace file
TRACEFILE="${BASEDIR}/log.trace"
touch "${TRACEFILE}"
if [ ${UID} -eq 0 ]; then
    /bin/chown nasroot:nasroot "${TRACEFILE}"
fi
exec 2>"${TRACEFILE}"
set -x

# Make log archive name
now=$(date +%Y-%m-%d-%H%M%S)
archive="foscripts-log-archive-${now}.tar.gz"

# Check if the script's dicrectory exists
if [ ! -d "${BASEDIR}" ]; then
    echo "Script directory ${BASEDIR} does not exist?"
    exit 1
fi

# Build a log archive file
/bin/tar czf "${HOMEDIR}/${archive}" "${BASEDIR}"
ret=$?
if [ ${ret} -ne 0 ]; then
    echo "Failed to archive script directory with tar command. ret=${ret}."
    echo "Please see ${TRACEFILE} for detail of the error."
    exit 1
fi

# Change owner of the archive to nasroot
if [ ${UID} -eq 0 ]; then
    /bin/chown nasroot:nasroot "${HOMEDIR}/${archive}"
    ret=$?
    if [ ${ret} -ne 0 ]; then
        echo "Failed to change owner of ${archive} to nasroot. ret=$?"
        echo "Please see ${TRACEFILE} for detail of the error."
        exit 1
    fi
fi

# Completed
echo "Log files are archived to ${HOMEDIR}/${archive}."
echo "Completed."

exit 0
